==> leatherman-1.12.8-2-aarch64.pkg.tar.xz: usr/lib/cmake/leatherman/LeathermanLibraries-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "leatherman_util" for configuration "None"
set_property(TARGET leatherman_util APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(leatherman_util PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/leatherman_util.so.1.12.8"
  IMPORTED_SONAME_NONE "leatherman_util.so.1.12.8"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_util )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_util "${_IMPORT_PREFIX}/lib/leatherman_util.so.1.12.8" )

# Import target "leatherman_locale" for configuration "None"
set_property(TARGET leatherman_locale APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(leatherman_locale PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "leatherman_util"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/leatherman_locale.so.1.12.8"
  IMPORTED_SONAME_NONE "leatherman_locale.so.1.12.8"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_locale )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_locale "${_IMPORT_PREFIX}/lib/leatherman_locale.so.1.12.8" )

# Import target "leatherman_logging" for configuration "None"
set_property(TARGET leatherman_logging APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(leatherman_logging PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "leatherman_locale"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/leatherman_logging.so.1.12.8"
  IMPORTED_SONAME_NONE "leatherman_logging.so.1.12.8"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_logging )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_logging "${_IMPORT_PREFIX}/lib/leatherman_logging.so.1.12.8" )

# Import target "leatherman_json_container" for configuration "None"
set_property(TARGET leatherman_json_container APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(leatherman_json_container PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "leatherman_locale"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/leatherman_json_container.so.1.12.8"
  IMPORTED_SONAME_NONE "leatherman_json_container.so.1.12.8"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_json_container )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_json_container "${_IMPORT_PREFIX}/lib/leatherman_json_container.so.1.12.8" )

# Import target "leatherman_file_util" for configuration "None"
set_property(TARGET leatherman_file_util APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(leatherman_file_util PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "leatherman_locale;leatherman_logging;leatherman_util"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/leatherman_file_util.so.1.12.8"
  IMPORTED_SONAME_NONE "leatherman_file_util.so.1.12.8"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_file_util )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_file_util "${_IMPORT_PREFIX}/lib/leatherman_file_util.so.1.12.8" )

# Import target "leatherman_curl" for configuration "None"
set_property(TARGET leatherman_curl APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(leatherman_curl PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "leatherman_locale;leatherman_logging;leatherman_util;leatherman_file_util"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/leatherman_curl.so.1.12.8"
  IMPORTED_SONAME_NONE "leatherman_curl.so.1.12.8"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_curl )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_curl "${_IMPORT_PREFIX}/lib/leatherman_curl.so.1.12.8" )

# Import target "leatherman_dynamic_library" for configuration "None"
set_property(TARGET leatherman_dynamic_library APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(leatherman_dynamic_library PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "leatherman_locale;leatherman_logging;leatherman_util"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/leatherman_dynamic_library.so.1.12.8"
  IMPORTED_SONAME_NONE "leatherman_dynamic_library.so.1.12.8"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_dynamic_library )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_dynamic_library "${_IMPORT_PREFIX}/lib/leatherman_dynamic_library.so.1.12.8" )

# Import target "leatherman_execution" for configuration "None"
set_property(TARGET leatherman_execution APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(leatherman_execution PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "leatherman_util;leatherman_locale;leatherman_logging;leatherman_file_util"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/leatherman_execution.so.1.12.8"
  IMPORTED_SONAME_NONE "leatherman_execution.so.1.12.8"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_execution )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_execution "${_IMPORT_PREFIX}/lib/leatherman_execution.so.1.12.8" )

# Import target "leatherman_ruby" for configuration "None"
set_property(TARGET leatherman_ruby APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(leatherman_ruby PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "leatherman_dynamic_library;leatherman_util;leatherman_execution;leatherman_locale;leatherman_logging"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/leatherman_ruby.so.1.12.8"
  IMPORTED_SONAME_NONE "leatherman_ruby.so.1.12.8"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_ruby )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_ruby "${_IMPORT_PREFIX}/lib/leatherman_ruby.so.1.12.8" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> leatherman-1.12.8-3-aarch64.pkg.tar.xz: usr/lib/cmake/leatherman/LeathermanLibraries-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "leatherman_util" for configuration "None"
set_property(TARGET leatherman_util APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(leatherman_util PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/leatherman_util.so.1.12.8"
  IMPORTED_SONAME_NONE "leatherman_util.so.1.12.8"
  )

list(APPEND _cmake_import_check_targets leatherman_util )
list(APPEND _cmake_import_check_files_for_leatherman_util "${_IMPORT_PREFIX}/lib/leatherman_util.so.1.12.8" )

# Import target "leatherman_locale" for configuration "None"
set_property(TARGET leatherman_locale APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(leatherman_locale PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "leatherman_util"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/leatherman_locale.so.1.12.8"
  IMPORTED_SONAME_NONE "leatherman_locale.so.1.12.8"
  )

list(APPEND _cmake_import_check_targets leatherman_locale )
list(APPEND _cmake_import_check_files_for_leatherman_locale "${_IMPORT_PREFIX}/lib/leatherman_locale.so.1.12.8" )

# Import target "leatherman_logging" for configuration "None"
set_property(TARGET leatherman_logging APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(leatherman_logging PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "leatherman_locale"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/leatherman_logging.so.1.12.8"
  IMPORTED_SONAME_NONE "leatherman_logging.so.1.12.8"
  )

list(APPEND _cmake_import_check_targets leatherman_logging )
list(APPEND _cmake_import_check_files_for_leatherman_logging "${_IMPORT_PREFIX}/lib/leatherman_logging.so.1.12.8" )

# Import target "leatherman_json_container" for configuration "None"
set_property(TARGET leatherman_json_container APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(leatherman_json_container PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "leatherman_locale"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/leatherman_json_container.so.1.12.8"
  IMPORTED_SONAME_NONE "leatherman_json_container.so.1.12.8"
  )

list(APPEND _cmake_import_check_targets leatherman_json_container )
list(APPEND _cmake_import_check_files_for_leatherman_json_container "${_IMPORT_PREFIX}/lib/leatherman_json_container.so.1.12.8" )

# Import target "leatherman_file_util" for configuration "None"
set_property(TARGET leatherman_file_util APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(leatherman_file_util PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "leatherman_locale;leatherman_logging;leatherman_util"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/leatherman_file_util.so.1.12.8"
  IMPORTED_SONAME_NONE "leatherman_file_util.so.1.12.8"
  )

list(APPEND _cmake_import_check_targets leatherman_file_util )
list(APPEND _cmake_import_check_files_for_leatherman_file_util "${_IMPORT_PREFIX}/lib/leatherman_file_util.so.1.12.8" )

# Import target "leatherman_curl" for configuration "None"
set_property(TARGET leatherman_curl APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(leatherman_curl PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "leatherman_locale;leatherman_logging;leatherman_util;leatherman_file_util"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/leatherman_curl.so.1.12.8"
  IMPORTED_SONAME_NONE "leatherman_curl.so.1.12.8"
  )

list(APPEND _cmake_import_check_targets leatherman_curl )
list(APPEND _cmake_import_check_files_for_leatherman_curl "${_IMPORT_PREFIX}/lib/leatherman_curl.so.1.12.8" )

# Import target "leatherman_dynamic_library" for configuration "None"
set_property(TARGET leatherman_dynamic_library APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(leatherman_dynamic_library PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "leatherman_locale;leatherman_logging;leatherman_util"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/leatherman_dynamic_library.so.1.12.8"
  IMPORTED_SONAME_NONE "leatherman_dynamic_library.so.1.12.8"
  )

list(APPEND _cmake_import_check_targets leatherman_dynamic_library )
list(APPEND _cmake_import_check_files_for_leatherman_dynamic_library "${_IMPORT_PREFIX}/lib/leatherman_dynamic_library.so.1.12.8" )

# Import target "leatherman_execution" for configuration "None"
set_property(TARGET leatherman_execution APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(leatherman_execution PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "leatherman_util;leatherman_locale;leatherman_logging;leatherman_file_util"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/leatherman_execution.so.1.12.8"
  IMPORTED_SONAME_NONE "leatherman_execution.so.1.12.8"
  )

list(APPEND _cmake_import_check_targets leatherman_execution )
list(APPEND _cmake_import_check_files_for_leatherman_execution "${_IMPORT_PREFIX}/lib/leatherman_execution.so.1.12.8" )

# Import target "leatherman_ruby" for configuration "None"
set_property(TARGET leatherman_ruby APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(leatherman_ruby PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "leatherman_dynamic_library;leatherman_util;leatherman_execution;leatherman_locale;leatherman_logging"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/leatherman_ruby.so.1.12.8"
  IMPORTED_SONAME_NONE "leatherman_ruby.so.1.12.8"
  )

list(APPEND _cmake_import_check_targets leatherman_ruby )
list(APPEND _cmake_import_check_files_for_leatherman_ruby "${_IMPORT_PREFIX}/lib/leatherman_ruby.so.1.12.8" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
